@@ -177,7 +177,7 @@ class Wsdl(WsdlBase):
                 lambda group: group(
                     _("Update the Build"),
                     normal=('cl_builder_prepared_id',
-                            'cl_builder_binhost_stable_set',
+                            'cl_builder_binhost_stable_opt_set',
                             'update.cl_update_binhost_recheck_set',),
                     expert=(
                         'update.cl_update_sync_only_set',
@@ -187,9 +187,11 @@ class Wsdl(WsdlBase):
                         'update.cl_update_emergelist_set',
                         'update.cl_update_check_rep_set',
                         'update.cl_update_world',
+                        'builder.cl_builder_gpg_force',
                         'update.cl_update_egencache_force',
                         'update.cl_update_eixupdate_force',
                         'cl_builder_rebuild_changed_set',
+                        'cl_builder_rebuilt_binaries_set',
                         'update.cl_update_skip_rb_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
@@ -200,18 +202,20 @@ class Wsdl(WsdlBase):
                         'cl_dispatch_conf'),
                     hide=(
                         'cl_builder_prepared_id',
-                        'cl_builder_binhost_stable_set',
+                        'cl_builder_binhost_stable_opt_set',
                         'update.cl_update_binhost_recheck_set',
                         'update.cl_update_sync_only_set',
                         'update.cl_update_other_set',
                         'update.cl_update_pretend_set',
                         'cl_builder_sync_rep',
+                        'builder.cl_builder_gpg_force',
                         'update.cl_update_emergelist_set',
                         'update.cl_update_check_rep_set',
                         'update.cl_update_world',
                         'update.cl_update_egencache_force',
                         'update.cl_update_eixupdate_force',
                         'cl_builder_rebuild_changed_set',
+                        'cl_builder_rebuilt_binaries_set',
                         'update.cl_update_skip_rb_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
@@ -223,7 +227,7 @@ class Wsdl(WsdlBase):
                         'cl_dispatch_conf'),
                     brief=(
                         'cl_builder_prepared_id',
-                        'cl_builder_binhost_stable_set',
+                        'cl_builder_binhost_stable_opt_set',
                         'update.cl_update_binhost_recheck_set',
                         'update.cl_update_sync_only_set',
                         'update.cl_update_other_set',
@@ -232,9 +236,11 @@ class Wsdl(WsdlBase):
                         'update.cl_update_emergelist_set',
                         'update.cl_update_check_rep_set',
                         'update.cl_update_world',
+                        'builder.cl_builder_gpg_force',
                         'update.cl_update_egencache_force',
                         'update.cl_update_eixupdate_force',
                         'cl_builder_rebuild_changed_set',
+                        'cl_builder_rebuilt_binaries_set',
                         'update.cl_update_skip_rb_set',
                         'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
